@@ -6,6 +6,8 @@ use warnings;
 use Time::HiRes qw( sleep );
 use Getopt::Long;
 
+use Future::AsyncAwait 0.47;
+
 use Device::Chip::Adapter;
 
 GetOptions(
@@ -13,12 +15,12 @@ GetOptions(
 ) or exit 1;
 
 my $adapter = Device::Chip::Adapter->new_from_description( $ADAPTER );
-my $proto = $adapter->make_protocol( "GPIO" )->get;
+my $proto = await $adapter->make_protocol( "GPIO" );
 
 my @gpios = $proto->list_gpios;
 
 while(1) {
-    my $gpios = $proto->read_gpios( [@gpios] )->get;
+    my $gpios = await $proto->read_gpios( [@gpios] );
     print "Read " .
         join( " ", map { "$_=" . ( $gpios->{$_} // "0" ) } sort keys %$gpios ) .
         "\n";
